==> maskingengine-1.0.0.tar.gz: maskingengine-1.0.0/docs/README.md <==
# MaskingEngine Documentation

Welcome to the MaskingEngine documentation! This directory contains comprehensive guides for using, customizing, and deploying MaskingEngine.

## 📖 Documentation Index

### Core Documentation
- **[Workflow Guide](workflows.md)** - Visual workflow diagrams and decision guide
- **[API Reference](api.md)** - Complete REST API documentation with examples
- **[Features Overview](features.md)** - Comprehensive feature documentation and capabilities
- **[Usage Examples](examples.md)** - Python SDK, CLI, API, and framework integration examples
- **[Architecture Overview](architecture.md)** - System design, components, and technical details

### Customization & Advanced Usage
- **[Custom Pattern Packs](patterns.md)** - Create organization-specific PII detection patterns

## 🚀 Quick Navigation

**New to MaskingEngine?** Start with the [main README](../README.md) for installation and quick start.

**Want to integrate MaskingEngine?** Check out [Usage Examples](examples.md) for your specific use case:
- Python SDK integration
- Command-line usage
- REST API integration
- Framework integrations (LangChain, Pandas, FastAPI)

**Need to customize PII detection?** Read the [Pattern Packs Guide](patterns.md) to create custom patterns.

**Planning a production deployment?** Review the [Architecture Overview](architecture.md) for performance and scaling guidance.

**Looking for specific API endpoints?** The [API Reference](api.md) has complete documentation with curl examples.

## 📋 Documentation Structure

```
docs/
├── README.md          # This file - documentation index
├── api.md            # REST API reference
├── architecture.md   # System architecture and design
├── examples.md       # Usage examples and integrations
├── features.md       # Complete feature documentation
└── patterns.md       # Custom pattern pack guide
```

## 🔗 External Resources

- **GitHub Repository**: [MaskingEngine on GitHub](https://github.com/maskingengine/maskingengine)
- **PyPI Package**: [maskingengine on PyPI](https://pypi.org/project/maskingengine/)
- **Issue Tracker**: [Report bugs and request features](https://github.com/maskingengine/maskingengine/issues)

## 📝 Contributing to Documentation

Found an error or want to improve the documentation? Contributions are welcome!

1. Fork the repository
2. Edit the relevant `.md` file
3. Submit a pull request with your improvements

All documentation is written in GitHub Flavored Markdown and should follow these guidelines:
- Use clear, concise language
- Include practical examples
- Test all code examples
- Link to related sections where helpful

==> maskingengine-1.1.0.tar.gz: maskingengine-1.1.0/docs/README.md <==
# MaskingEngine Documentation

Welcome to the MaskingEngine documentation! This directory contains comprehensive guides for using, customizing, and deploying MaskingEngine.

## 📖 Documentation Index

### Core Documentation
- **[Workflow Guide](workflows.md)** - Visual workflow diagrams and decision guide
- **[API Reference](api.md)** - Complete REST API documentation with examples
- **[Features Overview](features.md)** - Comprehensive feature documentation and capabilities
- **[Usage Examples](examples.md)** - Python SDK, CLI, API, and framework integration examples
- **[Architecture Overview](architecture.md)** - System design, components, and technical details

### Customization & Advanced Usage
- **[Custom Pattern Packs](patterns.md)** - Create organization-specific PII detection patterns
- **[Pattern Sourcing Guide](sourcing.md)** - Guidelines for developing and maintaining pattern packs
- **[Security Best Practices](security.md)** - Comprehensive security guidance and compliance recommendations

## 🚀 Quick Navigation

**New to MaskingEngine?** Start with the [main README](../README.md) for installation and quick start.

**Want to integrate MaskingEngine?** Check out [Usage Examples](examples.md) for your specific use case:
- Python SDK integration
- Command-line usage
- REST API integration
- Framework integrations (LangChain, Pandas, FastAPI)

**Need to customize PII detection?** Read the [Pattern Packs Guide](patterns.md) to create custom patterns.

**Planning a production deployment?** Review the [Architecture Overview](architecture.md) for performance and scaling guidance.

**Looking for specific API endpoints?** The [API Reference](api.md) has complete documentation with curl examples.

## 📋 Documentation Structure

```
docs/
├── README.md          # This file - documentation index
├── api.md            # REST API reference
├── architecture.md   # System architecture and design
├── examples.md       # Usage examples and integrations
├── features.md       # Complete feature documentation
└── patterns.md       # Custom pattern pack guide
```

## 🔗 External Resources

- **GitHub Repository**: [MaskingEngine on GitHub](https://github.com/foofork/maskingengine)
- **PyPI Package**: [maskingengine on PyPI](https://pypi.org/project/maskingengine/)
- **Issue Tracker**: [Report bugs and request features](https://github.com/foofork/maskingengine/issues)

## 📝 Contributing to Documentation

Found an error or want to improve the documentation? Contributions are welcome!

1. Fork the repository
2. Edit the relevant `.md` file
3. Submit a pull request with your improvements

All documentation is written in GitHub Flavored Markdown and should follow these guidelines:
- Use clear, concise language
- Include practical examples
- Test all code examples
- Link to related sections where helpful
